@@ -1,14 +1,14 @@
 use strict;
 use warnings;
 package Data::Rx::CoreType::any;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use base 'Data::Rx::CoreType';
 # ABSTRACT: the Rx //any type
 
 use Scalar::Util ();
 
-sub new {
+sub new_checker {
   my ($class, $arg, $rx) = @_;
 
   Carp::croak("unknown arguments to new")
@@ -49,7 +49,7 @@ Data::Rx::CoreType::any - the Rx //any type
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
